module motivation_response(
		input                 board_clk,
		input                 rstn,

		output                pll_lock_rx,
		output                pll_clkout0_rx,
		output                pll_clkout1_rx,
		output                pll_clkout2_rx,
		output                pll_clkout3_rx,
		output                rstn_rx,

		input                 clk_rx,
		input                 dout_en,
		input         [ 9:0]  dout,

        input                 inspect_clear,
		output    reg [ 1:0]  inspect_lock,
		output    reg         inspect_err,

		output                txp_o,
		output                txn_o

	);

wire			pll_lock_tx;
wire			pll_clkout0_tx;
reg		[15:0]	rstn_fabric_cnt;
reg				rstn_fabric;
wire            dat_lock;
wire            dat_err;

pll_hclk u_pll_hclk(
		.lock			(pll_lock_rx	), //output lock
		.clkout0		(pll_clkout0_rx	), //output clkout0
		.clkout1		(pll_clkout1_rx	), //output clkout1
		.clkout2		(pll_clkout2_rx	), //output clkout2
		.clkout3		(pll_clkout3_rx	), //output clkout3
		.clkin			(board_clk		), //input clkin
		.reset			(~rstn			) //input reset
	);

pll_hclk_tx u_pll_hclk_tx(
		.lock			(pll_lock_tx		), //output lock
		.clkout0		(pll_clkout0_tx		), //output clkout0
		.clkin			(board_clk			), //input clkin
		.reset			(~rstn				) //input reset
	);

always @(posedge board_clk or negedge rstn) begin
	if(!rstn) begin
		rstn_fabric_cnt	<=	16'd0;
	end else begin
		if(pll_lock_rx && pll_lock_tx) begin
			rstn_fabric_cnt	<=	rstn_fabric_cnt + 16'd1;
		end else begin
			rstn_fabric_cnt	<=	16'd0;
		end
	end
end

always @(posedge board_clk or negedge rstn) begin
	if(!rstn) begin
		rstn_fabric	<=	1'd0;
	end else begin
		if(pll_lock_rx && pll_lock_tx) begin
			if(rstn_fabric_cnt < 16'd20) begin
				rstn_fabric	<=	1'd0;
			end else begin
				rstn_fabric	<=	1'd1;
			end
		end else begin
			rstn_fabric	<=	1'd0;
		end
	end
end

assign	rstn_rx	=	rstn_fabric;

prbs_inspector u_prbs_inspector(
		.i_clk			(clk_rx						),
		.i_rst_n		(rstn_fabric                ),
		.i_prbs_enable	(1'b1						),
		.i_dat_vld		(dout_en					),
		.i_dat			(dout[7:0]					),
		.o_dat_err		(dat_err    				),
		.o_dat_lock		(dat_lock	    			),
		.o_dat_err_num	(							)
	);

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_lock[0] <=  1'd0;
    end else begin
        inspect_lock[0] <=  dat_lock;
    end
end

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_lock[1] <=  1'd0;
    end else if(~inspect_clear) begin
        inspect_lock[1] <=  1'd0;
    end else begin
        case(inspect_lock[1])
            1'd0:begin
                    if(~dat_lock && inspect_lock[0]) begin
                        inspect_lock[1] <=  1'd1;
                    end
                end
            default:    inspect_lock[1] <=  inspect_lock[1];
        endcase
    end
end

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_err <=  1'd0;
    end else if(~inspect_clear) begin
        inspect_err <=  1'd0;
    end else begin
        case(inspect_err)
            1'd0:begin
                    if(dat_lock && dat_err) begin
                        inspect_err <=  1'd1;
                    end
                end
            default:    inspect_err <=  inspect_err;
        endcase
    end
end

tx_module_top u_tx_module_top(
		.pll_clkout0_tx	(pll_clkout0_tx				),
		.pll_lock_tx	(pll_lock_tx				),

		.rstn_tx		(rstn_fabric				),

		.txp_o			(txp_o						),
		.txn_o			(txn_o						)
	);

endmodule

module prbs_inspector (
		i_clk,
		i_rst_n,
		i_prbs_enable,
		i_dat_vld,
		i_dat,
		o_dat_err,
		o_dat_lock,
		o_dat_err_num
	);
input i_clk;
input i_rst_n;
input i_prbs_enable;
input i_dat_vld;
input [7:0] i_dat;
output o_dat_err;
output o_dat_lock;
output [3:0] o_dat_err_num;
wire n45_4;
wire n47_3;
wire n49_3;
wire n51_3;
wire n53_3;
wire n55_3;
wire n57_3;
wire n59_3;
wire n158_3;
wire n150_18;
wire n149_20;
wire n148_22;
wire n147_14;
wire n194_6;
wire n193_6;
wire n192_6;
wire n191_7;
wire n109_5;
wire n108_5;
wire n107_5;
wire n164_5;
wire n158_4;
wire n158_5;
wire o_dat_lock_8;
wire o_dat_lock_9;
wire n150_19;
wire n150_20;
wire n149_21;
wire n149_22;
wire n149_23;
wire n148_23;
wire n148_24;
wire n194_7;
wire n110_6;
wire n109_6;
wire n108_6;
wire n107_6;
wire n148_25;
wire o_dat_err_num_3_9;
wire n149_26;
wire n110_12;
wire dat_corr_cnt_3_10;
wire n175_9;
wire dat_err_vld;
wire dat_err;
wire i_dat_vld_d1;
wire n6_6;
wire [7:0] i_dat_d1;
wire [8:0] shift_reg;
wire [7:0] dat_err_bit;
wire [3:0] dat_err_num;
wire [3:0] dat_corr_cnt;
wire VCC;
wire GND;
  LUT3 n45_s0 (
    .F(n45_4),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]),
    .I2(i_dat_d1[7]) 
);
defparam n45_s0.INIT=8'h96;
  LUT3 n47_s0 (
    .F(n47_3),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]),
    .I2(i_dat_d1[6]) 
);
defparam n47_s0.INIT=8'h96;
  LUT3 n49_s0 (
    .F(n49_3),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]),
    .I2(i_dat_d1[5]) 
);
defparam n49_s0.INIT=8'h96;
  LUT3 n51_s0 (
    .F(n51_3),
    .I0(shift_reg[5]),
    .I1(shift_reg[1]),
    .I2(i_dat_d1[4]) 
);
defparam n51_s0.INIT=8'h96;
  LUT3 n53_s0 (
    .F(n53_3),
    .I0(shift_reg[4]),
    .I1(shift_reg[0]),
    .I2(i_dat_d1[3]) 
);
defparam n53_s0.INIT=8'h96;
  LUT3 n55_s0 (
    .F(n55_3),
    .I0(i_dat_d1[7]),
    .I1(shift_reg[3]),
    .I2(i_dat_d1[2]) 
);
defparam n55_s0.INIT=8'h96;
  LUT3 n57_s0 (
    .F(n57_3),
    .I0(i_dat_d1[6]),
    .I1(shift_reg[2]),
    .I2(i_dat_d1[1]) 
);
defparam n57_s0.INIT=8'h96;
  LUT3 n59_s0 (
    .F(n59_3),
    .I0(i_dat_d1[5]),
    .I1(shift_reg[1]),
    .I2(i_dat_d1[0]) 
);
defparam n59_s0.INIT=8'h96;
  LUT4 n158_s0 (
    .F(n158_3),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(n158_4),
    .I3(n158_5) 
);
defparam n158_s0.INIT=16'hEFFF;
  LUT4 n150_s13 (
    .F(n150_18),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(n150_19),
    .I3(n150_20) 
);
defparam n150_s13.INIT=16'h6996;
  LUT4 n149_s14 (
    .F(n149_20),
    .I0(n149_21),
    .I1(n149_22),
    .I2(n149_23),
    .I3(n149_26) 
);
defparam n149_s14.INIT=16'h9669;
  LUT2 n148_s15 (
    .F(n148_22),
    .I0(n148_23),
    .I1(n148_24) 
);
defparam n148_s15.INIT=4'h9;
  LUT2 n147_s11 (
    .F(n147_14),
    .I0(n148_24),
    .I1(n148_23) 
);
defparam n147_s11.INIT=4'h4;
  LUT3 n194_s2 (
    .F(n194_6),
    .I0(n194_7),
    .I1(dat_err_num[0]),
    .I2(i_prbs_enable) 
);
defparam n194_s2.INIT=8'h80;
  LUT3 n193_s2 (
    .F(n193_6),
    .I0(n194_7),
    .I1(dat_err_num[1]),
    .I2(i_prbs_enable) 
);
defparam n193_s2.INIT=8'h80;
  LUT3 n192_s2 (
    .F(n192_6),
    .I0(n194_7),
    .I1(dat_err_num[2]),
    .I2(i_prbs_enable) 
);
defparam n192_s2.INIT=8'h80;
  LUT3 n191_s3 (
    .F(n191_7),
    .I0(n194_7),
    .I1(dat_err_num[3]),
    .I2(i_prbs_enable) 
);
defparam n191_s3.INIT=8'h80;
  LUT4 n109_s1 (
    .F(n109_5),
    .I0(o_dat_lock_9),
    .I1(n158_3),
    .I2(n109_6),
    .I3(i_prbs_enable) 
);
defparam n109_s1.INIT=16'h3400;
  LUT3 n108_s1 (
    .F(n108_5),
    .I0(n108_6),
    .I1(dat_corr_cnt[2]),
    .I2(n110_6) 
);
defparam n108_s1.INIT=8'h90;
  LUT4 n107_s1 (
    .F(n107_5),
    .I0(dat_corr_cnt[1]),
    .I1(n107_6),
    .I2(dat_corr_cnt[3]),
    .I3(i_prbs_enable) 
);
defparam n107_s1.INIT=16'hC200;
  LUT2 n164_s1 (
    .F(n164_5),
    .I0(i_prbs_enable),
    .I1(dat_err) 
);
defparam n164_s1.INIT=4'h8;
  LUT2 n158_s1 (
    .F(n158_4),
    .I0(dat_err_bit[3]),
    .I1(dat_err_bit[5]) 
);
defparam n158_s1.INIT=4'h1;
  LUT4 n158_s2 (
    .F(n158_5),
    .I0(dat_err_bit[2]),
    .I1(dat_err_bit[4]),
    .I2(dat_err_bit[6]),
    .I3(dat_err_bit[7]) 
);
defparam n158_s2.INIT=16'h0001;
  LUT4 o_dat_lock_s6 (
    .F(o_dat_lock_8),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[2]),
    .I2(dat_corr_cnt[1]),
    .I3(dat_corr_cnt[3]) 
);
defparam o_dat_lock_s6.INIT=16'h1000;
  LUT4 o_dat_lock_s7 (
    .F(o_dat_lock_9),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[1]),
    .I2(dat_corr_cnt[2]),
    .I3(dat_corr_cnt[3]) 
);
defparam o_dat_lock_s7.INIT=16'h0001;
  LUT4 n150_s14 (
    .F(n150_19),
    .I0(dat_err_bit[3]),
    .I1(dat_err_bit[5]),
    .I2(dat_err_bit[6]),
    .I3(dat_err_bit[7]) 
);
defparam n150_s14.INIT=16'h9669;
  LUT2 n150_s15 (
    .F(n150_20),
    .I0(dat_err_bit[2]),
    .I1(dat_err_bit[4]) 
);
defparam n150_s15.INIT=4'h9;
  LUT2 n149_s15 (
    .F(n149_21),
    .I0(dat_err_bit[2]),
    .I1(dat_err_bit[4]) 
);
defparam n149_s15.INIT=4'h8;
  LUT4 n149_s16 (
    .F(n149_22),
    .I0(dat_err_bit[1]),
    .I1(n150_19),
    .I2(n150_20),
    .I3(dat_err_bit[0]) 
);
defparam n149_s16.INIT=16'h9600;
  LUT4 n149_s17 (
    .F(n149_23),
    .I0(dat_err_bit[3]),
    .I1(dat_err_bit[5]),
    .I2(dat_err_bit[6]),
    .I3(dat_err_bit[7]) 
);
defparam n149_s17.INIT=16'h7EE8;
  LUT4 n148_s16 (
    .F(n148_23),
    .I0(n149_21),
    .I1(n149_23),
    .I2(n149_26),
    .I3(n149_22) 
);
defparam n148_s16.INIT=16'h6900;
  LUT4 n148_s17 (
    .F(n148_24),
    .I0(n149_21),
    .I1(n149_23),
    .I2(n149_26),
    .I3(n148_25) 
);
defparam n148_s17.INIT=16'h0071;
  LUT3 n194_s3 (
    .F(n194_7),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock_9),
    .I2(o_dat_lock) 
);
defparam n194_s3.INIT=8'h3A;
  LUT4 n110_s2 (
    .F(n110_6),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock_9),
    .I2(n158_3),
    .I3(i_prbs_enable) 
);
defparam n110_s2.INIT=16'h3500;
  LUT2 n109_s2 (
    .F(n109_6),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[1]) 
);
defparam n109_s2.INIT=4'h6;
  LUT3 n108_s2 (
    .F(n108_6),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[1]),
    .I2(n158_3) 
);
defparam n108_s2.INIT=8'hE7;
  LUT4 n107_s2 (
    .F(n107_6),
    .I0(dat_corr_cnt[1]),
    .I1(dat_corr_cnt[0]),
    .I2(dat_corr_cnt[2]),
    .I3(n158_3) 
);
defparam n107_s2.INIT=16'hFE7F;
  LUT4 n148_s18 (
    .F(n148_25),
    .I0(dat_err_bit[3]),
    .I1(dat_err_bit[5]),
    .I2(dat_err_bit[6]),
    .I3(dat_err_bit[7]) 
);
defparam n148_s18.INIT=16'h8000;
  LUT3 o_dat_err_num_3_s6 (
    .F(o_dat_err_num_3_9),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock),
    .I2(i_prbs_enable) 
);
defparam o_dat_err_num_3_s6.INIT=8'hEF;
  LUT4 n149_s19 (
    .F(n149_26),
    .I0(dat_err_bit[1]),
    .I1(n150_19),
    .I2(dat_err_bit[2]),
    .I3(dat_err_bit[4]) 
);
defparam n149_s19.INIT=16'hD44D;
  LUT4 n110_s4 (
    .F(n110_12),
    .I0(dat_corr_cnt[0]),
    .I1(n110_6),
    .I2(dat_err_vld),
    .I3(i_prbs_enable) 
);
defparam n110_s4.INIT=16'h4A44;
  LUT2 dat_corr_cnt_3_s4 (
    .F(dat_corr_cnt_3_10),
    .I0(dat_err_vld),
    .I1(i_prbs_enable) 
);
defparam dat_corr_cnt_3_s4.INIT=4'hB;
  LUT4 n175_s4 (
    .F(n175_9),
    .I0(i_prbs_enable),
    .I1(o_dat_lock),
    .I2(o_dat_lock_8),
    .I3(o_dat_lock_9) 
);
defparam n175_s4.INIT=16'h20A8;
  DFFCE i_dat_d1_7_s0 (
    .Q(i_dat_d1[7]),
    .D(i_dat[0]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_6_s0 (
    .Q(i_dat_d1[6]),
    .D(i_dat[1]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_5_s0 (
    .Q(i_dat_d1[5]),
    .D(i_dat[2]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_4_s0 (
    .Q(i_dat_d1[4]),
    .D(i_dat[3]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_3_s0 (
    .Q(i_dat_d1[3]),
    .D(i_dat[4]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_2_s0 (
    .Q(i_dat_d1[2]),
    .D(i_dat[5]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_1_s0 (
    .Q(i_dat_d1[1]),
    .D(i_dat[6]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_0_s0 (
    .Q(i_dat_d1[0]),
    .D(i_dat[7]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFPE shift_reg_7_s0 (
    .Q(shift_reg[7]),
    .D(i_dat_d1[7]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_6_s0 (
    .Q(shift_reg[6]),
    .D(i_dat_d1[6]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_5_s0 (
    .Q(shift_reg[5]),
    .D(i_dat_d1[5]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_4_s0 (
    .Q(shift_reg[4]),
    .D(i_dat_d1[4]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_3_s0 (
    .Q(shift_reg[3]),
    .D(i_dat_d1[3]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_2_s0 (
    .Q(shift_reg[2]),
    .D(i_dat_d1[2]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_1_s0 (
    .Q(shift_reg[1]),
    .D(i_dat_d1[1]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_0_s0 (
    .Q(shift_reg[0]),
    .D(i_dat_d1[0]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_vld_s0 (
    .Q(dat_err_vld),
    .D(i_dat_vld_d1),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_bit_7_s0 (
    .Q(dat_err_bit[7]),
    .D(n45_4),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_6_s0 (
    .Q(dat_err_bit[6]),
    .D(n47_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_5_s0 (
    .Q(dat_err_bit[5]),
    .D(n49_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_4_s0 (
    .Q(dat_err_bit[4]),
    .D(n51_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_3_s0 (
    .Q(dat_err_bit[3]),
    .D(n53_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_2_s0 (
    .Q(dat_err_bit[2]),
    .D(n55_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_1_s0 (
    .Q(dat_err_bit[1]),
    .D(n57_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_0_s0 (
    .Q(dat_err_bit[0]),
    .D(n59_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_num_3_s0 (
    .Q(dat_err_num[3]),
    .D(n147_14),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_2_s0 (
    .Q(dat_err_num[2]),
    .D(n148_22),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_1_s0 (
    .Q(dat_err_num[1]),
    .D(n149_20),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_0_s0 (
    .Q(dat_err_num[0]),
    .D(n150_18),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_s0 (
    .Q(dat_err),
    .D(n158_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE o_dat_err_s2 (
    .Q(o_dat_err),
    .D(n164_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_vld_d1_s0 (
    .Q(i_dat_vld_d1),
    .D(i_dat_vld),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFPE shift_reg_8_s0 (
    .Q(shift_reg[8]),
    .D(shift_reg[0]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_corr_cnt_3_s1 (
    .Q(dat_corr_cnt[3]),
    .D(n107_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_3_s1.INIT=1'b0;
  DFFCE dat_corr_cnt_2_s1 (
    .Q(dat_corr_cnt[2]),
    .D(n108_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_2_s1.INIT=1'b0;
  DFFCE dat_corr_cnt_1_s1 (
    .Q(dat_corr_cnt[1]),
    .D(n109_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_1_s1.INIT=1'b0;
  DFFCE o_dat_err_num_3_s3 (
    .Q(o_dat_err_num[3]),
    .D(n191_7),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_3_9) 
);
defparam o_dat_err_num_3_s3.INIT=1'b0;
  DFFCE o_dat_err_num_2_s2 (
    .Q(o_dat_err_num[2]),
    .D(n192_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_3_9) 
);
defparam o_dat_err_num_2_s2.INIT=1'b0;
  DFFCE o_dat_err_num_1_s2 (
    .Q(o_dat_err_num[1]),
    .D(n193_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_3_9) 
);
defparam o_dat_err_num_1_s2.INIT=1'b0;
  DFFCE o_dat_err_num_0_s2 (
    .Q(o_dat_err_num[0]),
    .D(n194_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_3_9) 
);
defparam o_dat_err_num_0_s2.INIT=1'b0;
  DFFCE dat_corr_cnt_0_s3 (
    .Q(dat_corr_cnt[0]),
    .D(n110_12),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
defparam dat_corr_cnt_0_s3.INIT=1'b0;
  DFFCE o_dat_lock_s8 (
    .Q(o_dat_lock),
    .D(n175_9),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
defparam o_dat_lock_s8.INIT=1'b0;
  INV n6_s2 (
    .O(n6_6),
    .I(i_rst_n) 
);
  VCC VCC_cZ (
    .V(VCC)
);
  GND GND_cZ (
    .G(GND)
);
  GSR GSR (
    .GSRI(VCC) 
);
endmodule

module tx_module_top (
		input		pll_clkout0_tx,
		input		pll_lock_tx,

		input		rstn_tx,

		output		txp_o,
		output		txn_o
	);

wire			pll_clkout0_div_tx;
wire			resetn;

wire	[ 7:0]	prbs_dout;
reg		[ 7:0]	k_in_cnt;
reg				k_in;
reg		[ 7:0]	data_in;
reg				rd_out;
wire			rdcomb_out;
wire	[ 9:0]	dat10b_encoded;
wire			dat1b_serial;

CLKDIV clkdiv_inst_tx(
		.HCLKIN			(pll_clkout0_tx		),
		.RESETN			(pll_lock_tx		),
		.CALIB 			(1'b0				),
		.CLKOUT			(pll_clkout0_div_tx	)
	);
defparam clkdiv_inst_tx.DIV_MODE="5";

assign	resetn	=	rstn_tx;

prbs_generator u_prbs_generator(
		.i_clk			(pll_clkout0_div_tx	),
		.i_rst_n		(resetn				),
		.i_rden			(1'b1				),
		.o_dout			(prbs_dout			)
	);

always @(posedge pll_clkout0_div_tx or negedge resetn) begin
	if(!resetn) begin
		k_in_cnt	<=	8'd0;
	end else if(k_in_cnt == 8'hff) begin
		k_in_cnt	<=	k_in_cnt;
	end else begin
		k_in_cnt	<=	k_in_cnt + 8'd1;
	end
end

always @(posedge pll_clkout0_div_tx or negedge resetn) begin
	if(!resetn) begin
		k_in	<=	1'd0;
	end else if( (k_in_cnt >= 8'd20) && (k_in_cnt <= 8'd40) ) begin
		k_in	<=	1'd1;
	end else begin
		k_in	<=	1'b0;
	end
end

always @(posedge pll_clkout0_div_tx or negedge resetn) begin
	if(!resetn) begin
		data_in	<=	8'd0;
	end else if( (k_in_cnt >= 8'd20) && (k_in_cnt <= 8'd40) ) begin
		data_in	<=	8'hbc;
	end else begin
		data_in	<=	prbs_dout;
	end
end

always @(posedge pll_clkout0_div_tx or negedge resetn) begin
	if(!resetn) begin
		rd_out	<=	1'd0;
	end else begin
		rd_out	<=	rdcomb_out;
	end
end

encoder_8b10b u_encoder_8b10b(
		.clk			(pll_clkout0_div_tx	),
		.rst			(~resetn			),
		.kin_ena		(k_in				),
		.ein_ena		(1'b1				),
		.ein_dat		(data_in			),
		.ein_rd			(rd_out				),
		.eout_val		(					),
		.eout_dat		(dat10b_encoded		),
		.eout_rdcomb	(rdcomb_out			),
		.eout_rdreg		(					)
	);

OSER10 u_OSER10(
		.Q				(dat1b_serial		),
		.D0				(dat10b_encoded[0]	),
		.D1				(dat10b_encoded[1]	),
		.D2				(dat10b_encoded[2]	),
		.D3				(dat10b_encoded[3]	),
		.D4				(dat10b_encoded[4]	),
		.D5				(dat10b_encoded[5]	),
		.D6				(dat10b_encoded[6]	),
		.D7				(dat10b_encoded[7]	),
		.D8				(dat10b_encoded[8]	),
		.D9				(dat10b_encoded[9]	),
		.PCLK			(pll_clkout0_div_tx	),
		.FCLK			(pll_clkout0_tx		),
		.RESET			(!resetn			)
	);

ELVDS_OBUF u_elvds_obuf(
		.I				(dat1b_serial		),
		.O				(txp_o				),
		.OB				(txn_o				)
	);

endmodule

module prbs_generator (
		i_clk,
		i_rst_n,
		i_rden,
		o_dout
	);
input i_clk;
input i_rst_n;
input i_rden;
output [7:0] o_dout;
wire n17_6;
wire [7:0] shift_reg_8_cal;
wire [8:0] shift_reg;
wire [7:0] o_dout_tmp;
wire VCC;
wire GND;
  LUT2 shift_reg_8_cal_0_s0 (
    .F(shift_reg_8_cal[0]),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]) 
);
defparam shift_reg_8_cal_0_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_1_s0 (
    .F(shift_reg_8_cal[1]),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]) 
);
defparam shift_reg_8_cal_1_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_2_s0 (
    .F(shift_reg_8_cal[2]),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]) 
);
defparam shift_reg_8_cal_2_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_3_s0 (
    .F(shift_reg_8_cal[3]),
    .I0(shift_reg[5]),
    .I1(shift_reg[1]) 
);
defparam shift_reg_8_cal_3_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_4_s0 (
    .F(shift_reg_8_cal[4]),
    .I0(shift_reg[4]),
    .I1(shift_reg[0]) 
);
defparam shift_reg_8_cal_4_s0.INIT=4'h6;
  LUT3 shift_reg_8_cal_5_s0 (
    .F(shift_reg_8_cal[5]),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]),
    .I2(shift_reg[3]) 
);
defparam shift_reg_8_cal_5_s0.INIT=8'h96;
  LUT3 shift_reg_8_cal_6_s0 (
    .F(shift_reg_8_cal[6]),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]),
    .I2(shift_reg[2]) 
);
defparam shift_reg_8_cal_6_s0.INIT=8'h96;
  LUT3 shift_reg_8_cal_7_s0 (
    .F(shift_reg_8_cal[7]),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]),
    .I2(shift_reg[1]) 
);
defparam shift_reg_8_cal_7_s0.INIT=8'h96;
  DFFPE shift_reg_7_s0 (
    .Q(shift_reg[7]),
    .D(shift_reg_8_cal[0]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_6_s0 (
    .Q(shift_reg[6]),
    .D(shift_reg_8_cal[1]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_5_s0 (
    .Q(shift_reg[5]),
    .D(shift_reg_8_cal[2]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_4_s0 (
    .Q(shift_reg[4]),
    .D(shift_reg_8_cal[3]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_3_s0 (
    .Q(shift_reg[3]),
    .D(shift_reg_8_cal[4]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_2_s0 (
    .Q(shift_reg[2]),
    .D(shift_reg_8_cal[5]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_1_s0 (
    .Q(shift_reg[1]),
    .D(shift_reg_8_cal[6]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_0_s0 (
    .Q(shift_reg[0]),
    .D(shift_reg_8_cal[7]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_7_s0 (
    .Q(o_dout_tmp[7]),
    .D(shift_reg_8_cal[7]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_6_s0 (
    .Q(o_dout_tmp[6]),
    .D(shift_reg_8_cal[6]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_5_s0 (
    .Q(o_dout_tmp[5]),
    .D(shift_reg_8_cal[5]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_4_s0 (
    .Q(o_dout_tmp[4]),
    .D(shift_reg_8_cal[4]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_3_s0 (
    .Q(o_dout_tmp[3]),
    .D(shift_reg_8_cal[3]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_2_s0 (
    .Q(o_dout_tmp[2]),
    .D(shift_reg_8_cal[2]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_1_s0 (
    .Q(o_dout_tmp[1]),
    .D(shift_reg_8_cal[1]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_0_s0 (
    .Q(o_dout_tmp[0]),
    .D(shift_reg_8_cal[0]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_7_s2 (
    .Q(o_dout[7]),
    .D(o_dout_tmp[7]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_6_s1 (
    .Q(o_dout[6]),
    .D(o_dout_tmp[6]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_5_s1 (
    .Q(o_dout[5]),
    .D(o_dout_tmp[5]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_4_s1 (
    .Q(o_dout[4]),
    .D(o_dout_tmp[4]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_3_s1 (
    .Q(o_dout[3]),
    .D(o_dout_tmp[3]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_2_s1 (
    .Q(o_dout[2]),
    .D(o_dout_tmp[2]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_1_s1 (
    .Q(o_dout[1]),
    .D(o_dout_tmp[1]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_0_s1 (
    .Q(o_dout[0]),
    .D(o_dout_tmp[0]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFPE shift_reg_8_s0 (
    .Q(shift_reg[8]),
    .D(shift_reg[0]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  INV n17_s2 (
    .O(n17_6),
    .I(i_rst_n) 
);
  VCC VCC_cZ (
    .V(VCC)
);
  GND GND_cZ (
    .G(GND)
);
  GSR GSR (
    .GSRI(VCC) 
);
endmodule

module encoder_8b10b (
		clk,
		rst,
		kin_ena,
		ein_ena,
		ein_dat,
		ein_rd,
		eout_val,
		eout_dat,
		eout_rdcomb,
		eout_rdreg
	);
input clk;
input rst;
input kin_ena;
input ein_ena;
input [7:0] ein_dat;
input ein_rd;
output eout_val;
output [9:0] eout_dat;
output eout_rdcomb;
output eout_rdreg;
wire a;
wire h;
wire n213_3;
wire b;
wire c;
wire d;
wire i;
wire f;
wire g;
wire j;
wire a_5;
wire h_4;
wire eout_rdcomb_d_3;
wire b_6;
wire c_6;
wire d_6;
wire e_6;
wire i_6;
wire f_6;
wire f_7;
wire j_6;
wire a_7;
wire a_8;
wire e_7;
wire i_7;
wire i_8;
wire f_8;
wire a_9;
wire a_10;
wire a_12;
wire e;
wire VCC;
wire GND;
  LUT2 a_s0 (
    .F(a),
    .I0(ein_dat[0]),
    .I1(a_5) 
);
defparam a_s0.INIT=4'h6;
  LUT2 h_s0 (
    .F(h),
    .I0(ein_dat[7]),
    .I1(h_4) 
);
defparam h_s0.INIT=4'h9;
  LUT4 eout_rdcomb_d_s (
    .F(eout_rdcomb),
    .I0(ein_dat[7]),
    .I1(ein_dat[5]),
    .I2(eout_rdcomb_d_3),
    .I3(ein_dat[6]) 
);
defparam eout_rdcomb_d_s.INIT=16'h78C3;
  LUT2 n213_s0 (
    .F(n213_3),
    .I0(kin_ena),
    .I1(ein_ena) 
);
defparam n213_s0.INIT=4'hE;
  LUT2 b_s1 (
    .F(b),
    .I0(b_6),
    .I1(a_5) 
);
defparam b_s1.INIT=4'h6;
  LUT3 c_s1 (
    .F(c),
    .I0(c_6),
    .I1(ein_dat[2]),
    .I2(a_5) 
);
defparam c_s1.INIT=8'h1E;
  LUT4 d_s1 (
    .F(d),
    .I0(ein_dat[2]),
    .I1(d_6),
    .I2(ein_dat[3]),
    .I3(a_5) 
);
defparam d_s1.INIT=16'h8F70;
  LUT2 i_s1 (
    .F(i),
    .I0(a_5),
    .I1(i_6) 
);
defparam i_s1.INIT=4'h9;
  LUT4 f_s1 (
    .F(f),
    .I0(f_6),
    .I1(ein_dat[5]),
    .I2(h_4),
    .I3(f_7) 
);
defparam f_s1.INIT=16'hE34B;
  LUT4 g_s1 (
    .F(g),
    .I0(ein_dat[5]),
    .I1(ein_dat[7]),
    .I2(ein_dat[6]),
    .I3(h_4) 
);
defparam g_s1.INIT=16'hF10E;
  LUT4 j_s1 (
    .F(j),
    .I0(f_7),
    .I1(f_6),
    .I2(j_6),
    .I3(h_4) 
);
defparam j_s1.INIT=16'hF40B;
  LUT4 a_s1 (
    .F(a_5),
    .I0(a_12),
    .I1(a_7),
    .I2(a_8),
    .I3(ein_rd) 
);
defparam a_s1.INIT=16'hBB0F;
  LUT4 h_s1 (
    .F(h_4),
    .I0(kin_ena),
    .I1(ein_dat[5]),
    .I2(ein_dat[6]),
    .I3(eout_rdcomb_d_3) 
);
defparam h_s1.INIT=16'h3FD4;
  LUT3 eout_rdcomb_d_s0 (
    .F(eout_rdcomb_d_3),
    .I0(a_8),
    .I1(a_7),
    .I2(ein_rd) 
);
defparam eout_rdcomb_d_s0.INIT=8'h87;
  LUT4 b_s2 (
    .F(b_6),
    .I0(ein_dat[0]),
    .I1(ein_dat[2]),
    .I2(ein_dat[3]),
    .I3(ein_dat[1]) 
);
defparam b_s2.INIT=16'h7F01;
  LUT4 c_s2 (
    .F(c_6),
    .I0(ein_dat[4]),
    .I1(ein_dat[3]),
    .I2(ein_dat[0]),
    .I3(ein_dat[1]) 
);
defparam c_s2.INIT=16'h000B;
  LUT2 d_s2 (
    .F(d_6),
    .I0(ein_dat[0]),
    .I1(ein_dat[1]) 
);
defparam d_s2.INIT=4'h8;
  LUT3 e_s2 (
    .F(e_6),
    .I0(e_7),
    .I1(ein_dat[4]),
    .I2(ein_dat[3]) 
);
defparam e_s2.INIT=8'h9E;
  LUT4 i_s2 (
    .F(i_6),
    .I0(kin_ena),
    .I1(i_7),
    .I2(ein_dat[4]),
    .I3(i_8) 
);
defparam i_s2.INIT=16'hDC0C;
  LUT3 f_s2 (
    .F(f_6),
    .I0(ein_dat[5]),
    .I1(ein_dat[6]),
    .I2(ein_dat[7]) 
);
defparam f_s2.INIT=8'h80;
  LUT4 f_s3 (
    .F(f_7),
    .I0(kin_ena),
    .I1(e_6),
    .I2(f_8),
    .I3(i_6) 
);
defparam f_s3.INIT=16'h5415;
  LUT3 j_s2 (
    .F(j_6),
    .I0(ein_dat[7]),
    .I1(ein_dat[5]),
    .I2(ein_dat[6]) 
);
defparam j_s2.INIT=8'h14;
  LUT3 a_s3 (
    .F(a_7),
    .I0(ein_dat[4]),
    .I1(a_9),
    .I2(kin_ena) 
);
defparam a_s3.INIT=8'h0D;
  LUT4 a_s4 (
    .F(a_8),
    .I0(ein_dat[1]),
    .I1(ein_dat[4]),
    .I2(a_10),
    .I3(ein_dat[3]) 
);
defparam a_s4.INIT=16'hF8CF;
  LUT4 e_s3 (
    .F(e_7),
    .I0(ein_dat[3]),
    .I1(ein_dat[0]),
    .I2(ein_dat[1]),
    .I3(ein_dat[2]) 
);
defparam e_s3.INIT=16'hABBC;
  LUT4 i_s3 (
    .F(i_7),
    .I0(ein_dat[0]),
    .I1(ein_dat[1]),
    .I2(ein_dat[2]),
    .I3(ein_dat[3]) 
);
defparam i_s3.INIT=16'hE997;
  LUT4 i_s4 (
    .F(i_8),
    .I0(ein_dat[0]),
    .I1(ein_dat[1]),
    .I2(ein_dat[2]),
    .I3(ein_dat[3]) 
);
defparam i_s4.INIT=16'h7FE8;
  LUT4 f_s4 (
    .F(f_8),
    .I0(a_12),
    .I1(a_7),
    .I2(ein_rd),
    .I3(a_8) 
);
defparam f_s4.INIT=16'h8CCF;
  LUT4 a_s5 (
    .F(a_9),
    .I0(ein_dat[0]),
    .I1(ein_dat[1]),
    .I2(ein_dat[2]),
    .I3(ein_dat[3]) 
);
defparam a_s5.INIT=16'h177E;
  LUT4 a_s6 (
    .F(a_10),
    .I0(ein_dat[1]),
    .I1(ein_dat[0]),
    .I2(ein_dat[2]),
    .I3(ein_dat[3]) 
);
defparam a_s6.INIT=16'h7E17;
  LUT4 a_s7 (
    .F(a_12),
    .I0(ein_dat[3]),
    .I1(ein_dat[2]),
    .I2(ein_dat[0]),
    .I3(ein_dat[1]) 
);
defparam a_s7.INIT=16'h4000;
  LUT4 e_s4 (
    .F(e),
    .I0(a_5),
    .I1(e_7),
    .I2(ein_dat[4]),
    .I3(ein_dat[3]) 
);
defparam e_s4.INIT=16'h6956;
  DFFCE eout_val_s2 (
    .Q(eout_val),
    .D(n213_3),
    .CLK(clk),
    .CLEAR(rst),
    .CE(VCC) 
);
  DFFCE eout_dat_9_s2 (
    .Q(eout_dat[9]),
    .D(j),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_8_s1 (
    .Q(eout_dat[8]),
    .D(h),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_7_s1 (
    .Q(eout_dat[7]),
    .D(g),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_6_s1 (
    .Q(eout_dat[6]),
    .D(f),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_5_s1 (
    .Q(eout_dat[5]),
    .D(i),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_4_s1 (
    .Q(eout_dat[4]),
    .D(e),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_3_s1 (
    .Q(eout_dat[3]),
    .D(d),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_2_s1 (
    .Q(eout_dat[2]),
    .D(c),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_1_s1 (
    .Q(eout_dat[1]),
    .D(b),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_dat_0_s1 (
    .Q(eout_dat[0]),
    .D(a),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  DFFCE eout_rdreg_s2 (
    .Q(eout_rdreg),
    .D(eout_rdcomb),
    .CLK(clk),
    .CLEAR(rst),
    .CE(n213_3) 
);
  VCC VCC_cZ (
    .V(VCC)
);
  GND GND_cZ (
    .G(GND)
);
  GSR GSR (
    .GSRI(VCC) 
);
endmodule
