module motivation_response(
		input                 board_clk,
		input                 rstn,

		output                pll_lock_rx,
		output                pll_clkout0_rx,
		output                pll_clkout1_rx,
		output                pll_clkout2_rx,
		output                pll_clkout3_rx,
		output                rstn_rx,

		input                 clk_rx,
		input                 dout_en,
		input         [19:0]  dout,

        input                 inspect_clear,
        output    reg [ 1:0]  inspect_lock,
        output    reg         inspect_err,

		output                txp_o,
		output                txn_o

	);

wire			pll_lock_tx;
wire			pll_clkout0_tx;
reg				rstn_fabric;
wire            dat_lock;
wire            dat_err;

pll_hclk u_pll_hclk(
		.lock			(pll_lock_rx	), //output lock
		.clkout0		(pll_clkout0_rx	), //output clkout0
		.clkout1		(pll_clkout1_rx	), //output clkout1
		.clkout2		(pll_clkout2_rx	), //output clkout2
		.clkout3		(pll_clkout3_rx	), //output clkout3
		.clkin			(board_clk		), //input clkin
		.reset			(~rstn			) //input reset
	);

pll_hclk_tx u_pll_hclk_tx(
		.lock			(pll_lock_tx		), //output lock
		.clkout0		(pll_clkout0_tx		), //output clkout0
		.clkin			(board_clk			), //input clkin
		.reset			(~rstn				) //input reset
	);

always @(posedge board_clk or negedge rstn) begin
	if(!rstn) begin
		rstn_fabric	<=	1'd0;
	end else begin
		if(pll_lock_rx && pll_lock_tx) begin
			rstn_fabric	<=	1'd1;
		end else begin
			rstn_fabric	<=	1'd0;
		end
	end
end

assign	rstn_rx	=	rstn_fabric;

prbs_inspector u_prbs_inspector(
		.i_clk			(clk_rx						),
		.i_rst_n		(rstn_fabric                ),
		.i_prbs_enable	(1'b1						),
		.i_dat_vld		(dout_en					),
		.i_dat			(dout 					    ),
        .o_dat_err      (dat_err                    ),
        .o_dat_lock     (dat_lock                   ),
		.o_dat_err_num	(							)
	);

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_lock[0] <=  1'd0;
    end else begin
        inspect_lock[0] <=  dat_lock;
    end
end

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_lock[1] <=  1'd0;
    end else if(~inspect_clear) begin
        inspect_lock[1] <=  1'd0;
    end else begin
        case(inspect_lock[1])
            1'd0:begin
                    if(~dat_lock && inspect_lock[0]) begin
                        inspect_lock[1] <=  1'd1;
                    end
                end
            default:    inspect_lock[1] <=  inspect_lock[1];
        endcase
    end
end

always @(posedge clk_rx or negedge rstn_fabric) begin
    if(!rstn_fabric) begin
        inspect_err <=  1'd0;
    end else if(~inspect_clear) begin
        inspect_err <=  1'd0;
    end else begin
        case(inspect_err)
            1'd0:begin
                    if(dat_lock && dat_err) begin
                        inspect_err <=  1'd1;
                    end
                end
            default:    inspect_err <=  inspect_err;
        endcase
    end
end

tx_module_top u_tx_module_top(
		.pll_clkout0_tx	(pll_clkout0_tx				),
		.pll_lock_tx	(pll_lock_tx				),

		.rstn_tx		(rstn_fabric				),

		.txp_o			(txp_o						),
		.txn_o			(txn_o						)
	);

endmodule

module prbs_inspector (
        i_clk,
        i_rst_n,
        i_prbs_enable,
        i_dat_vld,
        i_dat,
        o_dat_err,
        o_dat_lock,
        o_dat_err_num
    );
input i_clk;
input i_rst_n;
input i_prbs_enable;
input i_dat_vld;
input [19:0] i_dat;
output o_dat_err;
output o_dat_lock;
output [4:0] o_dat_err_num;
wire n57_4;
wire n59_3;
wire n61_3;
wire n63_3;
wire n65_3;
wire n67_3;
wire n69_3;
wire n71_3;
wire n73_3;
wire n75_3;
wire n77_3;
wire n79_3;
wire n81_3;
wire n83_3;
wire n85_3;
wire n87_3;
wire n89_3;
wire n91_3;
wire n93_3;
wire n95_3;
wire n294_3;
wire n285_48;
wire n284_49;
wire n283_53;
wire n332_6;
wire n331_6;
wire n330_6;
wire n329_6;
wire n328_7;
wire n170_5;
wire n169_5;
wire n167_5;
wire n300_5;
wire n294_4;
wire n294_5;
wire o_dat_lock_8;
wire o_dat_lock_9;
wire n285_49;
wire n285_50;
wire n284_50;
wire n284_51;
wire n284_52;
wire n284_53;
wire n283_54;
wire n283_56;
wire n283_57;
wire n282_59;
wire n332_7;
wire n170_6;
wire n169_6;
wire n168_6;
wire n167_6;
wire n294_6;
wire n294_7;
wire n294_8;
wire n294_9;
wire n285_51;
wire n285_52;
wire n285_53;
wire n285_54;
wire n284_54;
wire n284_55;
wire n284_56;
wire n284_57;
wire n283_58;
wire n283_59;
wire n284_58;
wire n284_59;
wire n284_60;
wire n281_37;
wire n282_61;
wire n283_61;
wire o_dat_err_num_4_9;
wire n168_12;
wire dat_corr_cnt_3_10;
wire n311_9;
wire dat_err_vld;
wire dat_err;
wire i_dat_vld_d1;
wire n6_6;
wire [19:0] i_dat_d1;
wire [8:0] shift_reg;
wire [19:0] dat_err_bit;
wire [4:0] dat_err_num;
wire [3:0] dat_corr_cnt;
wire VCC;
wire GND;
  LUT3 n57_s0 (
    .F(n57_4),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]),
    .I2(i_dat_d1[19]) 
);
defparam n57_s0.INIT=8'h96;
  LUT3 n59_s0 (
    .F(n59_3),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]),
    .I2(i_dat_d1[18]) 
);
defparam n59_s0.INIT=8'h96;
  LUT3 n61_s0 (
    .F(n61_3),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]),
    .I2(i_dat_d1[17]) 
);
defparam n61_s0.INIT=8'h96;
  LUT3 n63_s0 (
    .F(n63_3),
    .I0(shift_reg[5]),
    .I1(shift_reg[1]),
    .I2(i_dat_d1[16]) 
);
defparam n63_s0.INIT=8'h96;
  LUT3 n65_s0 (
    .F(n65_3),
    .I0(shift_reg[4]),
    .I1(shift_reg[0]),
    .I2(i_dat_d1[15]) 
);
defparam n65_s0.INIT=8'h96;
  LUT3 n67_s0 (
    .F(n67_3),
    .I0(i_dat_d1[19]),
    .I1(shift_reg[3]),
    .I2(i_dat_d1[14]) 
);
defparam n67_s0.INIT=8'h96;
  LUT3 n69_s0 (
    .F(n69_3),
    .I0(i_dat_d1[18]),
    .I1(shift_reg[2]),
    .I2(i_dat_d1[13]) 
);
defparam n69_s0.INIT=8'h96;
  LUT3 n71_s0 (
    .F(n71_3),
    .I0(i_dat_d1[17]),
    .I1(shift_reg[1]),
    .I2(i_dat_d1[12]) 
);
defparam n71_s0.INIT=8'h96;
  LUT3 n73_s0 (
    .F(n73_3),
    .I0(i_dat_d1[16]),
    .I1(shift_reg[0]),
    .I2(i_dat_d1[11]) 
);
defparam n73_s0.INIT=8'h96;
  LUT3 n75_s0 (
    .F(n75_3),
    .I0(i_dat_d1[19]),
    .I1(i_dat_d1[15]),
    .I2(i_dat_d1[10]) 
);
defparam n75_s0.INIT=8'h96;
  LUT3 n77_s0 (
    .F(n77_3),
    .I0(i_dat_d1[18]),
    .I1(i_dat_d1[14]),
    .I2(i_dat_d1[9]) 
);
defparam n77_s0.INIT=8'h96;
  LUT3 n79_s0 (
    .F(n79_3),
    .I0(i_dat_d1[17]),
    .I1(i_dat_d1[13]),
    .I2(i_dat_d1[8]) 
);
defparam n79_s0.INIT=8'h96;
  LUT3 n81_s0 (
    .F(n81_3),
    .I0(i_dat_d1[16]),
    .I1(i_dat_d1[12]),
    .I2(i_dat_d1[7]) 
);
defparam n81_s0.INIT=8'h96;
  LUT3 n83_s0 (
    .F(n83_3),
    .I0(i_dat_d1[15]),
    .I1(i_dat_d1[11]),
    .I2(i_dat_d1[6]) 
);
defparam n83_s0.INIT=8'h96;
  LUT3 n85_s0 (
    .F(n85_3),
    .I0(i_dat_d1[14]),
    .I1(i_dat_d1[10]),
    .I2(i_dat_d1[5]) 
);
defparam n85_s0.INIT=8'h96;
  LUT3 n87_s0 (
    .F(n87_3),
    .I0(i_dat_d1[13]),
    .I1(i_dat_d1[9]),
    .I2(i_dat_d1[4]) 
);
defparam n87_s0.INIT=8'h96;
  LUT3 n89_s0 (
    .F(n89_3),
    .I0(i_dat_d1[12]),
    .I1(i_dat_d1[8]),
    .I2(i_dat_d1[3]) 
);
defparam n89_s0.INIT=8'h96;
  LUT3 n91_s0 (
    .F(n91_3),
    .I0(i_dat_d1[11]),
    .I1(i_dat_d1[7]),
    .I2(i_dat_d1[2]) 
);
defparam n91_s0.INIT=8'h96;
  LUT3 n93_s0 (
    .F(n93_3),
    .I0(i_dat_d1[10]),
    .I1(i_dat_d1[6]),
    .I2(i_dat_d1[1]) 
);
defparam n93_s0.INIT=8'h96;
  LUT3 n95_s0 (
    .F(n95_3),
    .I0(i_dat_d1[9]),
    .I1(i_dat_d1[5]),
    .I2(i_dat_d1[0]) 
);
defparam n95_s0.INIT=8'h96;
  LUT4 n294_s0 (
    .F(n294_3),
    .I0(dat_err_bit[3]),
    .I1(dat_err_bit[7]),
    .I2(n294_4),
    .I3(n294_5) 
);
defparam n294_s0.INIT=16'hEFFF;
  LUT4 n285_s38 (
    .F(n285_48),
    .I0(dat_err_bit[2]),
    .I1(dat_err_bit[8]),
    .I2(n285_49),
    .I3(n285_50) 
);
defparam n285_s38.INIT=16'h6996;
  LUT4 n284_s39 (
    .F(n284_49),
    .I0(n284_50),
    .I1(n284_51),
    .I2(n284_52),
    .I3(n284_53) 
);
defparam n284_s39.INIT=16'h6996;
  LUT4 n283_s41 (
    .F(n283_53),
    .I0(n283_54),
    .I1(n283_61),
    .I2(n283_56),
    .I3(n283_57) 
);
defparam n283_s41.INIT=16'h9669;
  LUT3 n332_s2 (
    .F(n332_6),
    .I0(n332_7),
    .I1(dat_err_num[0]),
    .I2(i_prbs_enable) 
);
defparam n332_s2.INIT=8'h80;
  LUT3 n331_s2 (
    .F(n331_6),
    .I0(n332_7),
    .I1(dat_err_num[1]),
    .I2(i_prbs_enable) 
);
defparam n331_s2.INIT=8'h80;
  LUT3 n330_s2 (
    .F(n330_6),
    .I0(n332_7),
    .I1(dat_err_num[2]),
    .I2(i_prbs_enable) 
);
defparam n330_s2.INIT=8'h80;
  LUT3 n329_s2 (
    .F(n329_6),
    .I0(n332_7),
    .I1(dat_err_num[3]),
    .I2(i_prbs_enable) 
);
defparam n329_s2.INIT=8'h80;
  LUT3 n328_s3 (
    .F(n328_7),
    .I0(n332_7),
    .I1(dat_err_num[4]),
    .I2(i_prbs_enable) 
);
defparam n328_s3.INIT=8'h80;
  LUT4 n170_s1 (
    .F(n170_5),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock_9),
    .I2(n294_3),
    .I3(n170_6) 
);
defparam n170_s1.INIT=16'h3500;
  LUT4 n169_s1 (
    .F(n169_5),
    .I0(o_dat_lock_9),
    .I1(n294_3),
    .I2(i_prbs_enable),
    .I3(n169_6) 
);
defparam n169_s1.INIT=16'h4010;
  LUT4 n167_s1 (
    .F(n167_5),
    .I0(dat_corr_cnt[1]),
    .I1(n167_6),
    .I2(dat_corr_cnt[3]),
    .I3(i_prbs_enable) 
);
defparam n167_s1.INIT=16'hC200;
  LUT2 n300_s1 (
    .F(n300_5),
    .I0(i_prbs_enable),
    .I1(dat_err) 
);
defparam n300_s1.INIT=4'h8;
  LUT2 n294_s1 (
    .F(n294_4),
    .I0(dat_err_bit[15]),
    .I1(dat_err_bit[17]) 
);
defparam n294_s1.INIT=4'h1;
  LUT4 n294_s2 (
    .F(n294_5),
    .I0(n294_6),
    .I1(n294_7),
    .I2(n294_8),
    .I3(n294_9) 
);
defparam n294_s2.INIT=16'h8000;
  LUT4 o_dat_lock_s6 (
    .F(o_dat_lock_8),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[2]),
    .I2(dat_corr_cnt[1]),
    .I3(dat_corr_cnt[3]) 
);
defparam o_dat_lock_s6.INIT=16'h1000;
  LUT4 o_dat_lock_s7 (
    .F(o_dat_lock_9),
    .I0(dat_corr_cnt[0]),
    .I1(dat_corr_cnt[1]),
    .I2(dat_corr_cnt[2]),
    .I3(dat_corr_cnt[3]) 
);
defparam o_dat_lock_s7.INIT=16'h0001;
  LUT4 n285_s39 (
    .F(n285_49),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(dat_err_bit[3]),
    .I3(dat_err_bit[7]) 
);
defparam n285_s39.INIT=16'h9669;
  LUT4 n285_s40 (
    .F(n285_50),
    .I0(n285_51),
    .I1(n285_52),
    .I2(n285_53),
    .I3(n285_54) 
);
defparam n285_s40.INIT=16'h6996;
  LUT4 n284_s40 (
    .F(n284_50),
    .I0(dat_err_bit[2]),
    .I1(n285_49),
    .I2(dat_err_bit[8]),
    .I3(n285_50) 
);
defparam n284_s40.INIT=16'hB22B;
  LUT4 n284_s41 (
    .F(n284_51),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(dat_err_bit[3]),
    .I3(dat_err_bit[7]) 
);
defparam n284_s41.INIT=16'h7EE8;
  LUT4 n284_s42 (
    .F(n284_52),
    .I0(dat_err_bit[8]),
    .I1(n285_53),
    .I2(n285_54),
    .I3(n285_50) 
);
defparam n284_s42.INIT=16'hC355;
  LUT4 n284_s43 (
    .F(n284_53),
    .I0(n284_54),
    .I1(n284_55),
    .I2(n284_56),
    .I3(n284_57) 
);
defparam n284_s43.INIT=16'h6996;
  LUT4 n283_s42 (
    .F(n283_54),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(dat_err_bit[3]),
    .I3(dat_err_bit[7]) 
);
defparam n283_s42.INIT=16'h8000;
  LUT4 n283_s44 (
    .F(n283_56),
    .I0(n284_52),
    .I1(n284_56),
    .I2(n284_57),
    .I3(n284_53) 
);
defparam n283_s44.INIT=16'hC3AA;
  LUT4 n283_s45 (
    .F(n283_57),
    .I0(n284_50),
    .I1(n284_51),
    .I2(n284_52),
    .I3(n284_53) 
);
defparam n283_s45.INIT=16'h7117;
  LUT4 n282_s45 (
    .F(n282_59),
    .I0(n283_54),
    .I1(n283_57),
    .I2(n283_61),
    .I3(n283_56) 
);
defparam n282_s45.INIT=16'hD44D;
  LUT3 n332_s3 (
    .F(n332_7),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock_9),
    .I2(o_dat_lock) 
);
defparam n332_s3.INIT=8'h3A;
  LUT2 n170_s2 (
    .F(n170_6),
    .I0(dat_corr_cnt[0]),
    .I1(i_prbs_enable) 
);
defparam n170_s2.INIT=4'h4;
  LUT4 n169_s2 (
    .F(n169_6),
    .I0(dat_corr_cnt[3]),
    .I1(dat_corr_cnt[2]),
    .I2(dat_corr_cnt[0]),
    .I3(dat_corr_cnt[1]) 
);
defparam n169_s2.INIT=16'hF00E;
  LUT4 n168_s2 (
    .F(n168_6),
    .I0(n169_6),
    .I1(dat_corr_cnt[1]),
    .I2(n294_3),
    .I3(dat_corr_cnt[2]) 
);
defparam n168_s2.INIT=16'h28D7;
  LUT4 n167_s2 (
    .F(n167_6),
    .I0(dat_corr_cnt[1]),
    .I1(dat_corr_cnt[0]),
    .I2(dat_corr_cnt[2]),
    .I3(n294_3) 
);
defparam n167_s2.INIT=16'hFE7F;
  LUT4 n294_s3 (
    .F(n294_6),
    .I0(dat_err_bit[5]),
    .I1(dat_err_bit[6]),
    .I2(dat_err_bit[10]),
    .I3(dat_err_bit[11]) 
);
defparam n294_s3.INIT=16'h0001;
  LUT4 n294_s4 (
    .F(n294_7),
    .I0(dat_err_bit[8]),
    .I1(dat_err_bit[9]),
    .I2(dat_err_bit[12]),
    .I3(dat_err_bit[13]) 
);
defparam n294_s4.INIT=16'h0001;
  LUT4 n294_s5 (
    .F(n294_8),
    .I0(dat_err_bit[0]),
    .I1(dat_err_bit[1]),
    .I2(dat_err_bit[14]),
    .I3(dat_err_bit[16]) 
);
defparam n294_s5.INIT=16'h0001;
  LUT4 n294_s6 (
    .F(n294_9),
    .I0(dat_err_bit[2]),
    .I1(dat_err_bit[4]),
    .I2(dat_err_bit[18]),
    .I3(dat_err_bit[19]) 
);
defparam n294_s6.INIT=16'h0001;
  LUT3 n285_s41 (
    .F(n285_51),
    .I0(dat_err_bit[13]),
    .I1(dat_err_bit[14]),
    .I2(dat_err_bit[16]) 
);
defparam n285_s41.INIT=8'h96;
  LUT4 n285_s42 (
    .F(n285_52),
    .I0(dat_err_bit[15]),
    .I1(dat_err_bit[17]),
    .I2(dat_err_bit[18]),
    .I3(dat_err_bit[19]) 
);
defparam n285_s42.INIT=16'h9669;
  LUT4 n285_s43 (
    .F(n285_53),
    .I0(dat_err_bit[4]),
    .I1(dat_err_bit[5]),
    .I2(dat_err_bit[6]),
    .I3(dat_err_bit[12]) 
);
defparam n285_s43.INIT=16'h9669;
  LUT3 n285_s44 (
    .F(n285_54),
    .I0(dat_err_bit[9]),
    .I1(dat_err_bit[10]),
    .I2(dat_err_bit[11]) 
);
defparam n285_s44.INIT=8'h69;
  LUT4 n284_s44 (
    .F(n284_54),
    .I0(dat_err_bit[18]),
    .I1(dat_err_bit[19]),
    .I2(n284_58),
    .I3(n284_59) 
);
defparam n284_s44.INIT=16'h7887;
  LUT4 n284_s45 (
    .F(n284_55),
    .I0(dat_err_bit[13]),
    .I1(n285_52),
    .I2(dat_err_bit[16]),
    .I3(dat_err_bit[14]) 
);
defparam n284_s45.INIT=16'h2BB2;
  LUT3 n284_s46 (
    .F(n284_56),
    .I0(n285_54),
    .I1(dat_err_bit[12]),
    .I2(n285_53) 
);
defparam n284_s46.INIT=8'h3A;
  LUT4 n284_s47 (
    .F(n284_57),
    .I0(dat_err_bit[9]),
    .I1(dat_err_bit[10]),
    .I2(dat_err_bit[11]),
    .I3(n284_60) 
);
defparam n284_s47.INIT=16'hE817;
  LUT4 n283_s46 (
    .F(n283_58),
    .I0(n284_58),
    .I1(n284_59),
    .I2(n284_55),
    .I3(n284_54) 
);
defparam n283_s46.INIT=16'hEEF8;
  LUT3 n283_s47 (
    .F(n283_59),
    .I0(n284_60),
    .I1(n284_56),
    .I2(n284_57) 
);
defparam n283_s47.INIT=8'h5C;
  LUT4 n284_s48 (
    .F(n284_58),
    .I0(dat_err_bit[15]),
    .I1(dat_err_bit[17]),
    .I2(dat_err_bit[18]),
    .I3(dat_err_bit[19]) 
);
defparam n284_s48.INIT=16'h8EE8;
  LUT2 n284_s49 (
    .F(n284_59),
    .I0(dat_err_bit[14]),
    .I1(dat_err_bit[16]) 
);
defparam n284_s49.INIT=4'h8;
  LUT3 n284_s50 (
    .F(n284_60),
    .I0(dat_err_bit[4]),
    .I1(dat_err_bit[5]),
    .I2(dat_err_bit[6]) 
);
defparam n284_s50.INIT=8'hE8;
  LUT4 n281_s33 (
    .F(n281_37),
    .I0(n283_58),
    .I1(n283_59),
    .I2(n283_56),
    .I3(n282_59) 
);
defparam n281_s33.INIT=16'h002B;
  LUT4 n282_s46 (
    .F(n282_61),
    .I0(n283_58),
    .I1(n283_59),
    .I2(n283_56),
    .I3(n282_59) 
);
defparam n282_s46.INIT=16'h2BD4;
  LUT4 n283_s48 (
    .F(n283_61),
    .I0(n283_58),
    .I1(n284_60),
    .I2(n284_56),
    .I3(n284_57) 
);
defparam n283_s48.INIT=16'h995A;
  LUT3 o_dat_err_num_4_s6 (
    .F(o_dat_err_num_4_9),
    .I0(o_dat_lock_8),
    .I1(o_dat_lock),
    .I2(i_prbs_enable) 
);
defparam o_dat_err_num_4_s6.INIT=8'hEF;
  LUT4 n168_s4 (
    .F(n168_12),
    .I0(dat_corr_cnt[2]),
    .I1(i_prbs_enable),
    .I2(n168_6),
    .I3(dat_err_vld) 
);
defparam n168_s4.INIT=16'h0C88;
  LUT2 dat_corr_cnt_3_s4 (
    .F(dat_corr_cnt_3_10),
    .I0(i_prbs_enable),
    .I1(dat_err_vld) 
);
defparam dat_corr_cnt_3_s4.INIT=4'hD;
  LUT4 n311_s4 (
    .F(n311_9),
    .I0(i_prbs_enable),
    .I1(o_dat_lock),
    .I2(o_dat_lock_8),
    .I3(o_dat_lock_9) 
);
defparam n311_s4.INIT=16'h20A8;
  DFFCE i_dat_d1_19_s0 (
    .Q(i_dat_d1[19]),
    .D(i_dat[0]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_18_s0 (
    .Q(i_dat_d1[18]),
    .D(i_dat[1]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_17_s0 (
    .Q(i_dat_d1[17]),
    .D(i_dat[2]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_16_s0 (
    .Q(i_dat_d1[16]),
    .D(i_dat[3]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_15_s0 (
    .Q(i_dat_d1[15]),
    .D(i_dat[4]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_14_s0 (
    .Q(i_dat_d1[14]),
    .D(i_dat[5]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_13_s0 (
    .Q(i_dat_d1[13]),
    .D(i_dat[6]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_12_s0 (
    .Q(i_dat_d1[12]),
    .D(i_dat[7]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_11_s0 (
    .Q(i_dat_d1[11]),
    .D(i_dat[8]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_10_s0 (
    .Q(i_dat_d1[10]),
    .D(i_dat[9]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_9_s0 (
    .Q(i_dat_d1[9]),
    .D(i_dat[10]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_8_s0 (
    .Q(i_dat_d1[8]),
    .D(i_dat[11]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_7_s0 (
    .Q(i_dat_d1[7]),
    .D(i_dat[12]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_6_s0 (
    .Q(i_dat_d1[6]),
    .D(i_dat[13]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_5_s0 (
    .Q(i_dat_d1[5]),
    .D(i_dat[14]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_4_s0 (
    .Q(i_dat_d1[4]),
    .D(i_dat[15]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_3_s0 (
    .Q(i_dat_d1[3]),
    .D(i_dat[16]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_2_s0 (
    .Q(i_dat_d1[2]),
    .D(i_dat[17]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_1_s0 (
    .Q(i_dat_d1[1]),
    .D(i_dat[18]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_d1_0_s0 (
    .Q(i_dat_d1[0]),
    .D(i_dat[19]),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFPE shift_reg_7_s0 (
    .Q(shift_reg[7]),
    .D(i_dat_d1[7]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_6_s0 (
    .Q(shift_reg[6]),
    .D(i_dat_d1[6]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_5_s0 (
    .Q(shift_reg[5]),
    .D(i_dat_d1[5]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_4_s0 (
    .Q(shift_reg[4]),
    .D(i_dat_d1[4]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_3_s0 (
    .Q(shift_reg[3]),
    .D(i_dat_d1[3]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_2_s0 (
    .Q(shift_reg[2]),
    .D(i_dat_d1[2]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_1_s0 (
    .Q(shift_reg[1]),
    .D(i_dat_d1[1]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFPE shift_reg_0_s0 (
    .Q(shift_reg[0]),
    .D(i_dat_d1[0]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_vld_s0 (
    .Q(dat_err_vld),
    .D(i_dat_vld_d1),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_bit_19_s0 (
    .Q(dat_err_bit[19]),
    .D(n57_4),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_18_s0 (
    .Q(dat_err_bit[18]),
    .D(n59_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_17_s0 (
    .Q(dat_err_bit[17]),
    .D(n61_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_16_s0 (
    .Q(dat_err_bit[16]),
    .D(n63_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_15_s0 (
    .Q(dat_err_bit[15]),
    .D(n65_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_14_s0 (
    .Q(dat_err_bit[14]),
    .D(n67_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_13_s0 (
    .Q(dat_err_bit[13]),
    .D(n69_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_12_s0 (
    .Q(dat_err_bit[12]),
    .D(n71_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_11_s0 (
    .Q(dat_err_bit[11]),
    .D(n73_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_10_s0 (
    .Q(dat_err_bit[10]),
    .D(n75_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_9_s0 (
    .Q(dat_err_bit[9]),
    .D(n77_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_8_s0 (
    .Q(dat_err_bit[8]),
    .D(n79_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_7_s0 (
    .Q(dat_err_bit[7]),
    .D(n81_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_6_s0 (
    .Q(dat_err_bit[6]),
    .D(n83_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_5_s0 (
    .Q(dat_err_bit[5]),
    .D(n85_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_4_s0 (
    .Q(dat_err_bit[4]),
    .D(n87_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_3_s0 (
    .Q(dat_err_bit[3]),
    .D(n89_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_2_s0 (
    .Q(dat_err_bit[2]),
    .D(n91_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_1_s0 (
    .Q(dat_err_bit[1]),
    .D(n93_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_bit_0_s0 (
    .Q(dat_err_bit[0]),
    .D(n95_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_err_num_4_s0 (
    .Q(dat_err_num[4]),
    .D(n281_37),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_3_s0 (
    .Q(dat_err_num[3]),
    .D(n282_61),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_2_s0 (
    .Q(dat_err_num[2]),
    .D(n283_53),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_1_s0 (
    .Q(dat_err_num[1]),
    .D(n284_49),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_num_0_s0 (
    .Q(dat_err_num[0]),
    .D(n285_48),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE dat_err_s0 (
    .Q(dat_err),
    .D(n294_3),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE o_dat_err_s2 (
    .Q(o_dat_err),
    .D(n300_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFCE i_dat_vld_d1_s0 (
    .Q(i_dat_vld_d1),
    .D(i_dat_vld),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
  DFFPE shift_reg_8_s0 (
    .Q(shift_reg[8]),
    .D(i_dat_d1[8]),
    .CLK(i_clk),
    .PRESET(n6_6),
    .CE(i_dat_vld_d1) 
);
  DFFCE dat_corr_cnt_3_s1 (
    .Q(dat_corr_cnt[3]),
    .D(n167_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_3_s1.INIT=1'b0;
  DFFCE dat_corr_cnt_1_s1 (
    .Q(dat_corr_cnt[1]),
    .D(n169_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_1_s1.INIT=1'b0;
  DFFCE dat_corr_cnt_0_s1 (
    .Q(dat_corr_cnt[0]),
    .D(n170_5),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(dat_corr_cnt_3_10) 
);
defparam dat_corr_cnt_0_s1.INIT=1'b0;
  DFFCE o_dat_err_num_4_s3 (
    .Q(o_dat_err_num[4]),
    .D(n328_7),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_4_9) 
);
defparam o_dat_err_num_4_s3.INIT=1'b0;
  DFFCE o_dat_err_num_3_s2 (
    .Q(o_dat_err_num[3]),
    .D(n329_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_4_9) 
);
defparam o_dat_err_num_3_s2.INIT=1'b0;
  DFFCE o_dat_err_num_2_s2 (
    .Q(o_dat_err_num[2]),
    .D(n330_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_4_9) 
);
defparam o_dat_err_num_2_s2.INIT=1'b0;
  DFFCE o_dat_err_num_1_s2 (
    .Q(o_dat_err_num[1]),
    .D(n331_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_4_9) 
);
defparam o_dat_err_num_1_s2.INIT=1'b0;
  DFFCE o_dat_err_num_0_s2 (
    .Q(o_dat_err_num[0]),
    .D(n332_6),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(o_dat_err_num_4_9) 
);
defparam o_dat_err_num_0_s2.INIT=1'b0;
  DFFCE dat_corr_cnt_2_s3 (
    .Q(dat_corr_cnt[2]),
    .D(n168_12),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
defparam dat_corr_cnt_2_s3.INIT=1'b0;
  DFFCE o_dat_lock_s8 (
    .Q(o_dat_lock),
    .D(n311_9),
    .CLK(i_clk),
    .CLEAR(n6_6),
    .CE(VCC) 
);
defparam o_dat_lock_s8.INIT=1'b0;
  INV n6_s2 (
    .O(n6_6),
    .I(i_rst_n) 
);
  VCC VCC_cZ (
    .V(VCC)
);
  GND GND_cZ (
    .G(GND)
);
  GSR GSR (
    .GSRI(VCC) 
);
endmodule

module tx_module_top (
		input		pll_clkout0_tx,
		input		pll_lock_tx,

		input		rstn_tx,

		output		txp_o,
		output		txn_o
	);

wire			pll_clkout0_div_tx;
wire			resetn;

wire	[ 7:0]	prbs_dout;
wire			dat1b_serial;

CLKDIV clkdiv_inst_tx(
		.HCLKIN			(pll_clkout0_tx		),
		.RESETN			(pll_lock_tx		),
		.CALIB 			(1'b0				),
		.CLKOUT			(pll_clkout0_div_tx	)
	);
defparam clkdiv_inst_tx.DIV_MODE="4";

assign	resetn	=	rstn_tx;

prbs_generator u_prbs_generator(
		.i_clk			(pll_clkout0_div_tx	),
		.i_rst_n		(resetn				),
		.i_rden			(1'b1				),
		.o_dout			(prbs_dout			)
	);

OSER8 u_OSER8(
        .Q0             (dat1b_serial       ),
        .Q1             (                   ),
        .D0             (prbs_dout[0]       ),
        .D1             (prbs_dout[1]       ),
        .D2             (prbs_dout[2]       ),
        .D3             (prbs_dout[3]       ),
        .D4             (prbs_dout[4]       ),
        .D5             (prbs_dout[5]       ),
        .D6             (prbs_dout[6]       ), 
        .D7             (prbs_dout[7]       ), 
        .TX0            (1'b0               ),
        .TX1            (1'b0               ),
        .TX2            (1'b0               ),
        .TX3            (1'b0               ),
        .PCLK           (pll_clkout0_div_tx ),
        .FCLK           (pll_clkout0_tx     ),
        .RESET          (!resetn            )
    );
defparam u_OSER8.HWL ="false";
defparam u_OSER8.TXCLK_POL =1'b0;

ELVDS_OBUF u_elvds_obuf(
		.I				(dat1b_serial		),
		.O				(txp_o				),
		.OB				(txn_o				)
	);

endmodule

module prbs_generator (
		i_clk,
		i_rst_n,
		i_rden,
		o_dout
	);
input i_clk;
input i_rst_n;
input i_rden;
output [7:0] o_dout;
wire n17_6;
wire [7:0] shift_reg_8_cal;
wire [8:0] shift_reg;
wire [7:0] o_dout_tmp;
wire VCC;
wire GND;
  LUT2 shift_reg_8_cal_0_s0 (
    .F(shift_reg_8_cal[0]),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]) 
);
defparam shift_reg_8_cal_0_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_1_s0 (
    .F(shift_reg_8_cal[1]),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]) 
);
defparam shift_reg_8_cal_1_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_2_s0 (
    .F(shift_reg_8_cal[2]),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]) 
);
defparam shift_reg_8_cal_2_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_3_s0 (
    .F(shift_reg_8_cal[3]),
    .I0(shift_reg[5]),
    .I1(shift_reg[1]) 
);
defparam shift_reg_8_cal_3_s0.INIT=4'h6;
  LUT2 shift_reg_8_cal_4_s0 (
    .F(shift_reg_8_cal[4]),
    .I0(shift_reg[4]),
    .I1(shift_reg[0]) 
);
defparam shift_reg_8_cal_4_s0.INIT=4'h6;
  LUT3 shift_reg_8_cal_5_s0 (
    .F(shift_reg_8_cal[5]),
    .I0(shift_reg[8]),
    .I1(shift_reg[4]),
    .I2(shift_reg[3]) 
);
defparam shift_reg_8_cal_5_s0.INIT=8'h96;
  LUT3 shift_reg_8_cal_6_s0 (
    .F(shift_reg_8_cal[6]),
    .I0(shift_reg[7]),
    .I1(shift_reg[3]),
    .I2(shift_reg[2]) 
);
defparam shift_reg_8_cal_6_s0.INIT=8'h96;
  LUT3 shift_reg_8_cal_7_s0 (
    .F(shift_reg_8_cal[7]),
    .I0(shift_reg[6]),
    .I1(shift_reg[2]),
    .I2(shift_reg[1]) 
);
defparam shift_reg_8_cal_7_s0.INIT=8'h96;
  DFFPE shift_reg_7_s0 (
    .Q(shift_reg[7]),
    .D(shift_reg_8_cal[0]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_6_s0 (
    .Q(shift_reg[6]),
    .D(shift_reg_8_cal[1]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_5_s0 (
    .Q(shift_reg[5]),
    .D(shift_reg_8_cal[2]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_4_s0 (
    .Q(shift_reg[4]),
    .D(shift_reg_8_cal[3]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_3_s0 (
    .Q(shift_reg[3]),
    .D(shift_reg_8_cal[4]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_2_s0 (
    .Q(shift_reg[2]),
    .D(shift_reg_8_cal[5]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_1_s0 (
    .Q(shift_reg[1]),
    .D(shift_reg_8_cal[6]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFPE shift_reg_0_s0 (
    .Q(shift_reg[0]),
    .D(shift_reg_8_cal[7]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_7_s0 (
    .Q(o_dout_tmp[7]),
    .D(shift_reg_8_cal[7]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_6_s0 (
    .Q(o_dout_tmp[6]),
    .D(shift_reg_8_cal[6]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_5_s0 (
    .Q(o_dout_tmp[5]),
    .D(shift_reg_8_cal[5]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_4_s0 (
    .Q(o_dout_tmp[4]),
    .D(shift_reg_8_cal[4]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_3_s0 (
    .Q(o_dout_tmp[3]),
    .D(shift_reg_8_cal[3]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_2_s0 (
    .Q(o_dout_tmp[2]),
    .D(shift_reg_8_cal[2]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_1_s0 (
    .Q(o_dout_tmp[1]),
    .D(shift_reg_8_cal[1]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_tmp_0_s0 (
    .Q(o_dout_tmp[0]),
    .D(shift_reg_8_cal[0]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(i_rden) 
);
  DFFCE o_dout_7_s2 (
    .Q(o_dout[7]),
    .D(o_dout_tmp[7]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_6_s1 (
    .Q(o_dout[6]),
    .D(o_dout_tmp[6]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_5_s1 (
    .Q(o_dout[5]),
    .D(o_dout_tmp[5]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_4_s1 (
    .Q(o_dout[4]),
    .D(o_dout_tmp[4]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_3_s1 (
    .Q(o_dout[3]),
    .D(o_dout_tmp[3]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_2_s1 (
    .Q(o_dout[2]),
    .D(o_dout_tmp[2]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_1_s1 (
    .Q(o_dout[1]),
    .D(o_dout_tmp[1]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFCE o_dout_0_s1 (
    .Q(o_dout[0]),
    .D(o_dout_tmp[0]),
    .CLK(i_clk),
    .CLEAR(n17_6),
    .CE(VCC) 
);
  DFFPE shift_reg_8_s0 (
    .Q(shift_reg[8]),
    .D(shift_reg[0]),
    .CLK(i_clk),
    .PRESET(n17_6),
    .CE(i_rden) 
);
  INV n17_s2 (
    .O(n17_6),
    .I(i_rst_n) 
);
  VCC VCC_cZ (
    .V(VCC)
);
  GND GND_cZ (
    .G(GND)
);
  GSR GSR (
    .GSRI(VCC) 
);
endmodule